/**
 * Copyright 2018 The original authors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package io.dekorate.option.config;

import java.util.Map;

import io.dekorate.ConfigurationGenerator;
import io.dekorate.Session;
import io.dekorate.config.AnnotationConfiguration;
import io.dekorate.config.ConfigurationSupplier;
import io.dekorate.config.PropertyConfiguration;
import io.dekorate.kubernetes.config.Configuration;
import io.dekorate.option.adapter.JvmConfigAdapter;
import io.dekorate.option.configurator.ApplyJvmOptsConfigurator;

public interface JvmConfigGenerator extends ConfigurationGenerator {

  String JVM = "jvm";

  @Override
  default String getKey() {
    return JVM;
  }

  @Override
  default Class<? extends Configuration> getConfigType() {
    return JvmConfig.class;
  }

  @Override
  default void addAnnotationConfiguration(Map map) {
    on(new AnnotationConfiguration<>(
        JvmConfigAdapter
            .newBuilder(propertiesMap(map, JvmConfig.class))));
  }

  @Override
  default void addPropertyConfiguration(Map map) {
    on(new PropertyConfiguration<>(
        JvmConfigAdapter
            .newBuilder(propertiesMap(map, JvmConfig.class))));
  }

  default void on(ConfigurationSupplier<JvmConfig> config) {
    Session session = getSession();
    session.getConfigurationRegistry().add(config);
    session.getConfigurationRegistry().add(new ApplyJvmOptsConfigurator(config));
  }
}
